==> haskell-hasql-implicits-0.1.0.5-220-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-implicits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-implicits
version:              0.1.0.5
visibility:           public
id:                   hasql-implicits-0.1.0.5-647E1D9GGlsIf6n8vHCEhn
key:                  hasql-implicits-0.1.0.5-647E1D9GGlsIf6n8vHCEhn
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-implicits
synopsis:
    Implicit definitions for Hasql, such as default codecs for standard types

abi:                  de0dc09dc42c5e395976b2ba189df504
exposed:              True
exposed-modules:      Hasql.Implicits.Encoders
hidden-modules:       Hasql.Implicits.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-implicits-0.1.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-implicits-0.1.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-implicits-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-implicits
hs-libraries:         HShasql-implicits-0.1.0.5-647E1D9GGlsIf6n8vHCEhn
depends:
    aeson-2.1.2.1-9BF5sjMs3G4H72EdbKHz4V base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    hasql-1.5.0.5-cQbEibRfy7Gw1SAiUjlvU
    network-ip-0.3.0.3-KVgUpse3ah95013fkNMNCP
    scientific-0.3.7.0-I6iMwi20J4G9Jw2tSdEPEK text-2.0.2 time-1.12.2
    uuid-1.3.16-DTXFgrb7MThGeAanhZvVIB
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:
    /usr/share/doc/haskell-hasql-implicits/html/hasql-implicits.haddock

haddock-html:         /usr/share/doc/haskell-hasql-implicits/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-implicits-0.1.0.5-221-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-implicits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-implicits
version:              0.1.0.5
visibility:           public
id:                   hasql-implicits-0.1.0.5-1PBJpkqNkxS8CfMlUgUlZz
key:                  hasql-implicits-0.1.0.5-1PBJpkqNkxS8CfMlUgUlZz
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-implicits
synopsis:
    Implicit definitions for Hasql, such as default codecs for standard types

abi:                  bb933fe6704a43d7ea7176692ad60883
exposed:              True
exposed-modules:      Hasql.Implicits.Encoders
hidden-modules:       Hasql.Implicits.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-implicits-0.1.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-implicits-0.1.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-implicits-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-implicits
hs-libraries:         HShasql-implicits-0.1.0.5-1PBJpkqNkxS8CfMlUgUlZz
depends:
    aeson-2.1.2.1-H9spCVKCz3aBZuysSTfrjv base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    hasql-1.5.0.5-KQB6QYkcm8OblUyHVJ7GB
    network-ip-0.3.0.3-5WdjQywsMbF4EzdCNS1czL
    scientific-0.3.7.0-I6iMwi20J4G9Jw2tSdEPEK text-2.0.2 time-1.12.2
    uuid-1.3.16-DTXFgrb7MThGeAanhZvVIB
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:
    /usr/share/doc/haskell-hasql-implicits/html/hasql-implicits.haddock

haddock-html:         /usr/share/doc/haskell-hasql-implicits/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
